Взаимодействие с Libre.fm
Пред. | Глава 3. Настройка | След.

## Взаимодействие с Libre.fm

Libre.fm — это сервис скробблинга, аналогичный Last.fm, только полностью открытый и без дополнительных функций, вроде афиши или скачивания музыки. Подключается сервис добавлением в конфигурационный файл таких строк:

    libre_fm:
      login: alice
      password: secret

Для предотвращения скробблинга специфических дорожек — вроде джинглов — укажите их метки:

    libre_fm_skip_labels: [jingle, news, special]

Пред. | Наверх | След.
Взаимодействие с Last.fm | Начало | Доступ к количеству слушателей